package com.zanxiang.manage.service.Impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.manage.domain.dto.GameDTO;
import com.zanxiang.manage.domain.vo.GameChoiceVO;
import com.zanxiang.manage.service.GameService;
import com.zanxiang.mybatis.entity.Game;
import com.zanxiang.mybatis.mapper.GameMapper;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Service;
import org.springframework.util.CollectionUtils;

import java.util.Collections;
import java.util.List;
import java.util.Map;
import java.util.function.Function;
import java.util.stream.Collectors;

/**
 * @author : lingfeng
 * @time : 2022-06-24
 * @description : 游戏逻辑
 */
@Slf4j
@Service
public class GameServiceImpl extends ServiceImpl<GameMapper, Game> implements GameService {

    /**
     * 游戏选择列表查询
     *
     * @return : 返回所有游戏信息
     */
    @Override
    public List<GameChoiceVO> choiceList() {
        List<Game> gameList = super.list(new LambdaQueryWrapper<Game>().select(Game::getId, Game::getName));
        return BeanUtils.copyList(gameList, GameChoiceVO.class);
    }

    /**
     * 根据id查询游戏信息
     *
     * @param id : 游戏id
     * @return : 返回游戏信息
     */
    @Override
    public GameDTO getById(Long id) {
        if (id == null) {
            return null;
        }
        return BeanUtils.copy(super.getById(id), GameDTO.class);
    }

    /**
     * 游戏相关条件查询游戏信息
     *
     * @param cpId           : cp唯一键
     * @param gameId         : 游戏id
     * @param gameCategoryId : 分类id
     * @return : 返回游戏信息列表
     */
    @Override
    public Map<Long, GameDTO> gameCondition(Long cpId, Long gameId, Long gameCategoryId) {
        //游戏条件判断
        if (cpId == null && gameId == null && gameCategoryId == null) {
            return null;
        }
        List<GameDTO> gameList = this.getGameList(cpId, gameId, gameCategoryId);
        if (CollectionUtils.isEmpty(gameList)) {
            return Collections.emptyMap();
        }
        return gameList.stream().collect(Collectors.toMap(GameDTO::getId, Function.identity()));
    }

    /**
     * 游戏查询条件
     *
     * @param cpId           : cp唯一键
     * @param gameId         : 游戏id
     * @param gameCategoryId : 分类id
     * @return : 返回游戏信息列表, null 标识未匹配到游戏, 空表示没有条件
     */
    @Override
    public List<GameDTO> getGameList(Long cpId, Long gameId, Long gameCategoryId) {
        if (cpId == null && gameId == null && gameCategoryId == null) {
            return Collections.emptyList();
        }
        List<Game> gameList = super.list(new LambdaQueryWrapper<Game>()
                .eq(cpId != null, Game::getCpId, cpId)
                .eq(gameId != null, Game::getId, gameId)
                .eq(gameCategoryId != null, Game::getCategory, gameCategoryId)
                .select(Game::getId, Game::getCpId, Game::getName)
        );
        return BeanUtils.copyList(gameList, GameDTO.class);
    }

}
