package com.zanxiang.manage.service.Impl;

import com.alibaba.nacos.common.utils.CollectionUtils;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.zanxiang.common.enums.DeleteEnum;
import com.zanxiang.common.exception.ParamNullException;
import com.zanxiang.common.utils.JsonUtil;
import com.zanxiang.common.utils.StringUtils;
import com.zanxiang.common.utils.bean.BeanUtils;
import com.zanxiang.manage.domain.bo.PayMerchantBO;
import com.zanxiang.manage.domain.mapper.GameStrategyListMapper;
import com.zanxiang.manage.domain.params.GamePayWayListParam;
import com.zanxiang.manage.domain.params.GameStrategyListParam;
import com.zanxiang.manage.domain.params.GameStrategyParam;
import com.zanxiang.manage.domain.params.PayMerchantListParam;
import com.zanxiang.manage.domain.vo.GameStrategyListVO;
import com.zanxiang.manage.domain.vo.PayApplicationVO;
import com.zanxiang.manage.domain.vo.PayMerchantListVO;
import com.zanxiang.manage.service.*;
import com.zanxiang.mybatis.entity.*;
import com.zanxiang.mybatis.mapper.GameStrategyMapper;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;
import java.util.stream.Collectors;

/**
 * 游戏策略 服务实现类
 *
 * @author xufeng
 * @date 2022-07-01 11:38
 */
@Service
public class GameStrategyServiceImpl extends ServiceImpl<GameStrategyMapper, GameStrategy> implements GameStrategyService {

    @Autowired
    private GameService gameService;

    @Autowired
    private GameCategoryService gameCategoryService;

    @Autowired
    private GamePayWayService gamePayWayService;

    @Autowired
    private PayMerchantService payMerchantService;

    @Autowired
    private GameStrategyListMapper gameStrategyListMapper;

    @Autowired
    private PayBoxService payBoxService;

    @Override
    public Boolean saveOrUpdate(GameStrategyParam bo) {
        if (bo.getIsDelete() != null && bo.getIsDelete() == DeleteEnum.YES.getCode()) {
            if (bo.getId() == null) {
                throw new ParamNullException("Id");
            }
            return removeById(bo.getId());
        }
        GameStrategy gameStrategy = BeanUtils.copy(bo, GameStrategy.class);
        if (bo.getOrderConfig() != null && !bo.getOrderConfig().equals("")) {
            gameStrategy.setConfig(JsonUtil.toString(bo.getOrderConfig()));
        }
        return saveOrUpdate(gameStrategy);
    }

    @Override
    public IPage<GameStrategyListVO> list(GameStrategyListParam bo) {

        Page<GameStrategy> gameStrategyPage = new Page<>(bo.getPageNum(), bo.getPageSize());
        IPage<GameStrategyListVO> list = gameStrategyListMapper.List(gameStrategyPage, bo.getName(), bo.getType(), bo.getStatus(), bo.getGameId());
        if (list.getTotal() == 0) {
            return null;
        }
        List<GameStrategyListVO> data = list.getRecords();

        HashMap<Long, String> gamePayWayMap = new HashMap<>();

        //获取商户号列表
        List<PayMerchant> payMerchantList = payMerchantService.list();
        Map<String, PayMerchant> payMerchantData = payMerchantList.stream().collect(Collectors.toMap(PayMerchant::getMerchantNo, PayMerchant -> PayMerchant));

        data.stream().forEach(t -> {
            //支付方式 -   避免重复查询，已获取则缓存
            if (gamePayWayMap.get(t.getGameId()) == null) {
                List<GamePayWay> gamePayWayList = gamePayWayService.list(new QueryWrapper<GamePayWay>().lambda().eq(GamePayWay::getGameId, t.getGameId()));
                if (CollectionUtils.isNotEmpty(gamePayWayList)) {
                    String payWayName = gamePayWayList.stream().map(b -> b.getPayWayName()).collect(Collectors.joining(","));
                    t.setGamePayWay(payWayName);
                }
                gamePayWayMap.put(t.getGameId(), t.getGamePayWay());
                if (StringUtils.isNotEmpty(t.getPayMerchant())) {
                    t.setApplicationMerchant(payBoxService.getMerchantDetail(payMerchantData, t.getPayMerchant()));
                }
            }

        });
        return list;
    }

    private GameStrategyListVO toVo(GameStrategy gameStrategy) {
        if (Objects.isNull(gameStrategy)) {
            return null;
        }
        return BeanUtils.copy(gameStrategy, GameStrategyListVO.class);
    }
}
